# Nonebot Plugin SparkGPT

## 详细文档 -> [Canxin Site](https://canxin121.github.io/p/sparkgpt/)

## Feature

- 使用Nonebot框架跨适配器实现,多聊天平台同步实现
- 支持 QQ, QQ频道, Kook, 飞书, Telegram, Discord
- 支持跨平台账户绑定,多平台账户统一数据
- 适配多来源语言模型, 多态模型
- 实现 多用户, 多会话窗口, 公共会话和私有会话
- 实现 流式输出 , 文转图, 文转网络剪切板链接 
- 实现WebUi编辑配置,实时热更新
  
## ToDo
- 负载均衡
- 用户权限系统

## 模型来源支持情况
✔️:支持 ❌:不支持  

| 来源         | 传入文本 | 传入图片 | 输出文本 | 输出图片 |
| ------------ | -------- | -------- | -------- | -------- |
| Newbing      | ✔️        | ✔️        | ✔️        | ✔️        |
| Poe          | ✔️        | ❌        | ✔️        | ❌        |
| ChatGPT Api  | ✔️        | ❌        | ✔️        | ❌        |
| ChatGPT 网页 | ✔️        | ❌        | ✔️        | ❌        |
| Claude.Ai    | ✔️        | ❌        | ✔️        | ❌        |
| Slack Claude | ✔️        | ❌        | ✔️        | ❌        |
  
Ps: `各来源的配置使用均在WebUi中已有详细说明`

## 聊天平台支持情况
✔️:支持 ❌:不支持  

| 来源     | 传入文本 | 传入图片 | 输出文本 | 输出图片 |
| -------- | -------- | -------- | -------- | -------- |
| QQ       | ✔️        | ✔️        | ✔️        | ✔️        |
| QQ频道   | ✔️        | ✔️        | ✔️        | ✔️        |
| Kook     | ✔️        | ❌        | ✔️        | ✔️        |
| 飞书     | ✔️        | ❌        | ✔️        | ✔️        |
| Telegram | ✔️        | ✔️        | ✔️        | ✔️        |
| Discord  | ✔️        | ✔️        | ✔️        | ✔️        |
  
Ps: `各聊天平台接入,请查看对应的Nonebot适配器使用说明`